Enum AnyControlTube

pub enum AnyControlTube {
    Balloon(Tube),
    Disk(Tube),
    Fs(Tube),
    Gpu(Tube),
    IrqTube(Tube),
    PvClock(Tube),
    Snd(Tube),
    Vm(Tube),
    VmMemoryTube {
        tube: Tube,
        expose_with_viommu: bool,
    },
    VmMsync(Tube),
}
All the tube types that can be “registered” with the platform specific fn run_control implementation. These tubes are generally one half of a tube pair, with the other half held by a device.

Variants



Balloon(Tube)



Disk(Tube)



Fs(Tube)

Receives FsMappingRequest.



Gpu(Tube)



IrqTube(Tube)

Receives IrqHandlerRequest.



PvClock(Tube)



Snd(Tube)



Vm(Tube)

Receives VmRequest.



VmMemoryTube

Fields

tube: Tube
expose_with_viommu: bool

See devices::virtio::VirtioDevice.expose_shared_memory_region_with_viommu



VmMsync(Tube)

Receives VmMemoryMappingRequest.