Enum DeviceControlRequest

pub enum DeviceControlRequest {
    Gpe {
        gpe: u32,
        clear_evt: Option<Event>,
    },
    PciPme(u16),
    HotPlugVfioCommand {
        device: HotPlugDeviceInfo,
        add: bool,
    },
}
A request from a device to the main process to perform some operation on the VM.

Variants



Gpe

Inject a general-purpose event. If clear_evt is provided, when the irq associated with the GPE is resampled, it will be re-asserted as long as clear_evt is not signaled.

Fields

gpe: u32
clear_evt: Option<Event>


PciPme(u16)

Inject a PCI PME.



HotPlugVfioCommand

Command to add/remove multiple vfio-pci devices.

Fields

add: bool

Implementations

Source

impl DeviceControlRequest

pub fn execute( &self, pm: &mut Option<Arc<Mutex<dyn PmResource + Send>>>, ) -> DeviceControlResponse

Executes this request on the given VM power management resource.