Enum IrqSetup

pub enum IrqSetup<'a> {
    Event(u32, &'a Event, DeviceId, usize, String),
    Route(IrqRoute),
    UnRegister(u32, &'a Event),
}
Data to set up an IRQ event or IRQ route on the IRQ chip. VmIrqRequest::execute can’t take an IrqChip argument, because of a dependency cycle between devices and vm_control, so it takes a Fn that processes an IrqSetup.

Variants



Event(u32, &'a Event, DeviceId, usize, String)



Route(IrqRoute)



UnRegister(u32, &'a Event)