Enum VmIrqRequest

pub enum VmIrqRequest {
    AllocateOneMsi {
        irqfd: Event,
        device_id: DeviceId,
        queue_id: usize,
        device_name: String,
    },
    AllocateOneMsiAtGsi {
        irqfd: Event,
        gsi: u32,
        device_id: DeviceId,
        queue_id: usize,
        device_name: String,
    },
    AddMsiRoute {
        gsi: u32,
        msi_address: u64,
        msi_data: u32,
    },
    ReleaseOneIrq {
        gsi: u32,
        irqfd: Event,
    },
}

Variants



AllocateOneMsi

Allocate one gsi, and associate gsi to irqfd with register_irqfd()

Fields

irqfd: Event
device_id: DeviceId
queue_id: usize
device_name: String


AllocateOneMsiAtGsi

Allocate a specific gsi to irqfd with register_irqfd(). This must only be used when it is known that the gsi is free. Only the snapshot subsystem can make this guarantee, and use of this request by any other caller is strongly discouraged.

Fields

irqfd: Event
gsi: u32
device_id: DeviceId
queue_id: usize
device_name: String


AddMsiRoute

Add one msi route entry into the IRQ chip.

Fields

gsi: u32
msi_address: u64
msi_data: u32


ReleaseOneIrq

Fields

gsi: u32
irqfd: Event

Implementations

Source

impl VmIrqRequest

pub fn execute<F>( &self, set_up_irq: F, sys_allocator: &mut SystemAllocator, ) -> VmIrqResponse
where F: FnOnce(IrqSetup<'_>) -> Result<()>,

Executes this request on the given Vm.

Arguments
  • set_up_irq - A function that applies an IrqSetup to an IRQ chip.

This does not return a result, instead encapsulating the success or failure in a VmIrqResponse with the intended purpose of sending the response back over the socket that received this VmIrqResponse.