pub enum VmRunMode {
Running,
Suspending,
Exiting,
Breakpoint,
}Expand description
Mode of execution for the VM.
Variants
Running
The default run mode indicating the VCPUs are running.
Suspending
Indicates that the VCPUs are suspending execution until the Running mode is set.
Exiting
Indicates that the VM is exiting all processes.
Breakpoint
Indicates that the VM is in a breakpoint waiting for the debugger to do continue.