pub struct BalloonTube {
tube: Tube,
pending_queue: VecDeque<(BalloonControlCommand, Option<usize>)>,
pending_adjust_with_completion: Option<(u64, usize)>,
}Expand description
Utility for multiplexing a balloon tube between multiple control tubes. Commands are sent and processed serially.
Fields
tube: Tubepending_queue: VecDeque<(BalloonControlCommand, Option<usize>)>pending_adjust_with_completion: Option<(u64, usize)>Implementations
Sourceimpl BalloonTube
impl BalloonTube
pub fn new(tube: Tube) -> Self
Sourcepub fn send_cmd(
&mut self,
cmd: BalloonControlCommand,
key: Option<usize>,
) -> Option<(VmResponse, usize)>
pub fn send_cmd( &mut self, cmd: BalloonControlCommand, key: Option<usize>, ) -> Option<(VmResponse, usize)>
Sends or queues the given command to this tube. Associates the response with the given key.