pub struct DeviceSleepGuard<'a> {
pub(crate) device_control_tube: &'a Tube,
pub(crate) devices_state: DevicesState,
}Expand description
A guard to guarantee that all devices are sleeping during its scope.
When this guard is dropped, it wakes the devices.
Fields
device_control_tube: &'a Tubedevices_state: DevicesStateImplementations