pub struct VcpuRestoreRequest {
pub result_sender: Sender<Result<()>>,
pub snapshot_reader: SnapshotReader,
pub host_tsc_reference_moment: u64,
}Expand description
Request to restore a Vcpu from a given snapshot, and report the results back via the provided channel.
Fields
result_sender: Sender<Result<()>>snapshot_reader: SnapshotReaderhost_tsc_reference_moment: u64Trait Implementations
Sourceimpl Clone for VcpuRestoreRequest
impl Clone for VcpuRestoreRequest
Sourcefn clone(&self) -> VcpuRestoreRequest
fn clone(&self) -> VcpuRestoreRequest
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for VcpuRestoreRequest
impl RefUnwindSafe for VcpuRestoreRequest
impl Send for VcpuRestoreRequest
impl Sync for VcpuRestoreRequest
impl Unpin for VcpuRestoreRequest
impl UnwindSafe for VcpuRestoreRequest