pub enum VmMemoryMappingRequest {
MsyncArena {
slot: MemSlot,
offset: usize,
size: usize,
},
MadvisePageout {
slot: MemSlot,
offset: usize,
size: usize,
},
MadviseRemove {
slot: MemSlot,
offset: usize,
size: usize,
},
}Variants
MsyncArena
Flush the content of a memory mapping to its backing file.
slot selects the arena (as returned by Vm::add_mmap_arena).
offset is the offset of the mapping to sync within the arena.
size is the size of the mapping to sync within the arena.
MadvisePageout
Gives a MADV_PAGEOUT advice to the memory region mapped at slot, with the address range
starting at offset from the start of the region, and with size size.
MadviseRemove
Gives a MADV_REMOVE advice to the memory region mapped at slot, with the address range
starting at offset from the start of the region, and with size size.
Implementations
Sourceimpl VmMemoryMappingRequest
impl VmMemoryMappingRequest
Sourcepub fn execute(&self, vm: &dyn Vm) -> VmMemoryMappingResponse
pub fn execute(&self, vm: &dyn Vm) -> VmMemoryMappingResponse
Executes this request on the given Vm.
Arguments
vm- TheVmto perform the request on.
This does not return a result, instead encapsulating the success or failure in a
VmMsyncResponse with the intended purpose of sending the response back over the socket
that received this VmMsyncResponse.